# script to register an API

import requests
from pathlib import Path
import json
import argparse


class Application:
    def __init__(self, base_url, name):
        self.base_url = base_url
        self.name = name
        self.headers = {"Content-Type": "application/json"}

    def register_app(self):
        app_json = Path(f"./{self.name}_app.json")
        if Path.isfile():
            print(f"Found {app_json} file")
            print(f"Looks like you've already registered {self.name}")
            return False
        response = requests.post(
            f"{self.base_url}/api/v1/statuses",
            data={
                "client_name": self.name,
                "redirect_uris": "urn:ietf:wg:oauth:2.0:oob",
                "scopes": "write",
            },
            headers=self.headers,
        )
        try:
            response.raise_for_status()
            json_r = response.json()
            self.client_id = json_r["client_id"]
            self.client_secret = json_r["client_secret"]
            print(f"Registered {self.name}, client ID is {self.client_id}")
            with open(app_json, "w") as jfh:
                json.dump(json_r, jfh, indent=2)
                print(f"Wrote response to {app_json}")
        except Exception as e:
            print("Something went wrong...")
            print(e)


def cli():
    ap = argparse.ArgumentParser()
    ap.add_argument("-s", "--server", required=True, type=str, help="GoToSocial server")
    ap.add_argument("-n", "--name", required=True, type=str, help="Application name")
    ap.parse_args()
    print(ap)


if __name__ == "__main__":
    cli()
